<?php

namespace Drupal\bulk_update_user_roles\Batch;

use Drupal\user\Entity\User;

/**
 * {@inheritdoc}
 */
class BulkUpdateUserRoles {

  /**
   * Batch operation to assign roles to a user.
   */
  public static function addRolesToUser($uid, $roles_list, &$context) {
    if (empty($context['results']['count'])) {
      $context['results']['count'] = 0;
      $context['results']['type'] = 'add';
    }

    $user = User::load($uid);
    if ($user) {
      foreach ($roles_list as $role) {
        $user->addRole($role);
      }
      $user->save();
    }

    $context['results']['count']++;
  }

  /**
   * Batch operation to remove roles from a user.
   */
  public static function removeRolesFromUser($uid, $roles_list, &$context) {
    if (empty($context['results']['count'])) {
      $context['results']['count'] = 0;
      $context['results']['type'] = 'remove';
    }

    $user = User::load($uid);
    if ($user) {
      foreach ($roles_list as $role) {
        $user->removeRole($role);
      }
      $user->save();
    }

    $context['results']['count']++;
  }

  /**
   * Batch finished callback.
   */
  public static function finished($success, $results, $operations) {
    if ($success) {
      $message = $results['type'] === 'add'
        ? \Drupal::translation()->formatPlural($results['count'], 'Assigned role to 1 user.', 'Assigned role to @count users.')
        : \Drupal::translation()->formatPlural($results['count'], 'Removed role from 1 user.', 'Removed role from @count users.');
      \Drupal::messenger()->addMessage($message);
    }
    else {
      \Drupal::messenger()->addMessage(t('An error occurred while processing.'));
    }
  }

}
